Vmxnet3 nic on windows - deployed on vcenter

Hi.
I’m on a fresh install of vonecloud running opennebula 5.6.1. I’ve added the vcenter (6.5 U2), storage and network to ONE, and imported a template. Deploying a VM from this template makes the NIC an E1000 NIC, and I need to use the vmxnet3 NIC.

This is my /etc/one/vcenter_driver.default

< VCENTER>
< VM>
< TEMPLATE>
< NIC>
< MODEL>vmxnet3
< /NIC>
< /TEMPLATE>
< /VM>
< IMAGE>
< TEMPLATE>
< DEV_PREFIX>sd</DEV_PREFIX>
< VCENTER_DISK_TYPE>thin</DISK_TYPE>
< VCENTER_ADAPTER_TYPE>lsiLogic</ADAPTER_TYPE>
< /TEMPLATE>
< /IMAGE>
< /VCENTER>

and this is my vmm_exec_vcenter.conf:

NIC=[MODEL=“VirtualVmxnet3”]

Even setting the NIC type on the VM does not change the NIC on the VM.

Can anyone help me with this isssue?

best regards

Markus

Hi Markus,

I am running into the same issue. Whenever attaching my freshly imported virtual network (after changing both vmm_exec_vcenter.conf and vcenter_driver.default), I too, get a E1000 adapter attached rather than VMXNET3.

I’m also looking to get this resolved.

Edit:
For now, I have just edited the vCenter driver to use vmxnet3 by default so I can continue my deployment for now.

--- /usr/lib/one/ruby/vcenter_driver/virtual_machine.rb-dd20190109MB    2018-09-20 13:42:36.000000000 +0200
+++ /usr/lib/one/ruby/vcenter_driver/virtual_machine.rb 2019-01-09 12:49:56.645292028 +0100
@@ -1946,8 +1946,8 @@
                             RbVmomi::VIM::VirtualVmxnet2
                         when "virtualvmxnet3", "vmxnet3"
                             RbVmomi::VIM::VirtualVmxnet3
-                        else # If none matches, use VirtualE1000
-                            RbVmomi::VIM::VirtualE1000
+                        else # If none matches, use VirtualVmxnet3
+                            RbVmomi::VIM::VirtualVmxnet3
                    end

         if network.class == RbVmomi::VIM::Network

This will be solved finally in 5.8: https://github.com/OpenNebula/one/issues/2827

Deploy it with vCenter?